@@ -1,22 +1,25 @@
-#! /bin/sh
+#! /bin/bash
 #
 # Minimal allow_read generator.
 #
-# Copyright (C) 2005-2006  NTT DATA CORPORATION
+# Copyright (C) 2005-2007  NTT DATA CORPORATION
 #
-# Version: 1.3.1   2006/12/08
+# Version: 1.3.2   2007/02/14
 #
 # Run this script and add the output to /etc/ccs/exception_policy.txt .
 # You MUST review the content of /etc/ccs/exception_policy.txt
 # because there would be redundant or dangerous entries.
 #
 
+cd ${0%/*}
+export PATH=$PWD:/sbin:/bin:${PATH}
+
 #
 # Allow reading some data files.
 #
 for i in /etc/ld.so.cache /proc/meminfo /proc/sys/kernel/version /etc/localtime /usr/lib/gconv/gconv-modules.cache /usr/lib/locale/locale-archive /usr/share/locale/locale.alias /usr/share/locale/ja/LC_MESSAGES/coreutils.mo /usr/share/locale/ja/LC_MESSAGES/libc.mo
 do
-	FILE=`readlink -f $i`
+	FILE=`realpath $i`
 	[ -n "$FILE" -a -r "$FILE" -a ! -L "$FILE" ] && echo 'allow_read '$FILE
 done
 
@@ -33,6 +36,6 @@ done
 #
 for i in `ldconfig -NXp | grep -F '=>' | awk ' { print $NF } ' | sort | uniq`
 do
-	FILE=`readlink -f $i`
+	FILE=`realpath $i`
 	[ -n "$FILE" -a -s "$FILE" -a ! -L "$FILE" ] && echo 'allow_read '$FILE
 done | sort | uniq
